# USGBD2015format.R - N Maizlish - January 6, 2020
# This program reformats output from the GBD Data tool
# at http://ghdx.healthdata.org/gbd-results-tool
# in the ITHIM age-sex-cause categories
# You must adjust colon cancer separately and merge population data

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Initialize Progrram
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# turn off scientific notation in data frames
options(scipen=999)
setwd("C:/Users/Noneof/Documents/HealthLinks/ITHIM_MPO/USA/CalibrationData/USGBD")

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Read CDC Wonder files for colorectal and colon cancers and make proportion
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

colorectal <- read.delim(file="Colo-rectalCancers2015USA.txt", header = TRUE, sep = "\t", quote = "\"'")
colon      <- read.delim(file="ColonCancers2015USA.txt", header = TRUE, sep = "\t", quote = "\"'")

colorectal <- colorectal[1:47,c("Gender","Five.Year.Age.Groups.Code","Deaths")]
names(colorectal)[names(colorectal)=="Deaths"] <- "CRdeaths"
colon      <- colon[1:47,c("Gender","Five.Year.Age.Groups.Code","Deaths")]

colon  <- cbind(colon,colorectal["CRdeaths"])

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Reformat Age and Sex Categories for ITHIM
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

age_5groups <- function(x) { 
  if    (is.na(x)) y <- "NA"
  else if (x == "1")        y <- 0
  else if (x == "1-4")      y <- 0
  else if (x == "5-9")      y <- 5
  else if (x == "10-14")    y <- 5
  else if (x == "15-19")    y <- 15
  else if (x == "20-24")    y <- 15
  else if (x == "25-29")    y <- 15
  else if (x == "30-34")    y <- 30
  else if (x == "35-39")    y <- 30
  else if (x == "40-44")    y <- 30
  else if (x == "45-49")    y <- 45
  else if (x == "50-54")    y <- 45
  else if (x == "55-59")    y <- 45
  else if (x == "60-64")    y <- 60
  else if (x == "65-69")    y <- 60
  else if (x == "70-74")    y <- 70
  else if (x == "75-79")    y <- 70
  else if (x == "80-84")    y <- 80
  else if (x == "85-89")    y <- 80
  else if (x == "90-94")    y <- 80
  else if (x == "95-99")    y <- 80
  else if (x == "100+")     y <- 80
  else y <- "Total"
  return(y)
}

colon$Age  <- as.numeric(sapply(colon$Five.Year.Age.Groups.Code,age_5groups))
colon$Sex  <- ifelse(colon$Gender == "Male", 1, 2)
colon <- colon[!is.na(colon$Age), c("Age","Sex","CRdeaths","Deaths")]

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Aggregate by ITHIM Age Categories
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

colon16 <- aggregate(. ~ Sex+Age, data = colon, FUN="sum")
colon16$proportion <- ifelse(colon16$CRdeaths > 0, colon16$Deaths/colon16$CRdeaths, 1)
colon16$cause <- "Colon and rectum cancer"

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Read US GBD file 2015 file
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

usbd <- read.csv(file= "IHME-GBD_2017_DATA-bafc2a33-1.csv",  
                 head = TRUE, sep = "," , stringsAsFactors = FALSE)

# Drop Ages  1 to 4
usbd <- usbd[usbd$age_name != "1 to 4",]

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Create Age categories for aggregation
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

age_groups <- function(x) { 
  if    (is.na(x)) y <- "NA"
  else if (x == "Under 5")     y <- 0
  else if (x == "5 to 9")      y <- 5
  else if (x == "10 to 14")    y <- 5
  else if (x == "15 to 19")    y <- 15
  else if (x == "20 to 24")    y <- 15
  else if (x == "25 to 29")    y <- 15
  else if (x == "30 to 34")    y <- 30
  else if (x == "35 to 39")    y <- 30
  else if (x == "40 to 44")    y <- 30
  else if (x == "45 to 49")    y <- 45
  else if (x == "50 to 54")    y <- 45
  else if (x == "55 to 59")    y <- 45
  else if (x == "60 to 64")    y <- 60
  else if (x == "65 to 69")    y <- 60
  else if (x == "70 to 74")    y <- 70
  else if (x == "75 to 79")    y <- 70
  else if (x == "80 plus")     y <- 80
  else y <- "Total"
  return(y)
}

usbd$Age  <- sapply(usbd$age_name,age_groups)

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Create Cause categories for aggregation
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Acute respiratory infections in children
ari <- usbd[usbd$cause_name %in% c("Upper respiratory infections", 
           "Lower respiratory infections") & usbd$age_name == "Under 5", ]
names(ari)[names(ari) == "cause_name"] <- "cause"

usbd$cause <- ifelse (usbd$cause_name %in% 
 c("Asthma", 
 "Chronic obstructive pulmonary disease",
 "Pneumoconiosis", 
 "Upper respiratory infections",
 "Interstitial lung disease and pulmonary sarcoidosis",
 "Lower respiratory infections",
 "Other chronic respiratory diseases"),"Respiratory diseases", usbd$cause_name)

# Rename sex_id to Sex
colnames(usbd)[colnames(usbd) == "sex_id"] <- "Sex"
colnames(ari)[colnames(ari)   == "sex_id"] <- "Sex"

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Aggregate value field by age, sex, cause, & outcome (deaths, yld, yll, daly)
# Add acure respiratory infections in chaldren as separate file
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

usbd16 <- aggregate(val ~ measure_name+cause+Sex+Age, data = usbd, FUN="sum")
ari1   <- aggregate(val ~ measure_name+Sex+Age, data = ari,  FUN="sum")
ari1$cause <- "Acute resp infections"
usbd16 <- rbind(usbd16,ari1)


# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# subset file by health outcome 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

daly <-   usbd16[usbd16$measure_name == "DALYs (Disability-Adjusted Life Years)", 
                 c("cause", "Sex","Age", "val")]
names(daly)[names(daly)=="val"] <- "daly"

yll <-    usbd16[usbd16$measure_name == "YLLs (Years of Life Lost)",  
                 c("cause", "Sex","Age", "val")]
names(yll)[names(yll)=="val"] <- "yll"

yld <-    usbd16[usbd16$measure_name == "YLDs (Years Lived with Disability)", 
                 c("cause", "Sex","Age", "val")]
names(yld)[names(yld)=="val"] <- "yld"

deaths <- usbd16[usbd16$measure_name == "Deaths",  
                 c("cause", "Sex","Age", "val")]
names(deaths)[names(deaths)=="val"] <- "deaths"


# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# merge files on cause, age and sex
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gbd <- merge(daly,   yll, by = c("cause", "Sex", "Age"), all.x = T)
gbd <- merge(gbd,    yld, by = c("cause", "Sex", "Age"), all.x = T)
gbd <- merge(gbd, deaths, by = c("cause", "Sex", "Age"), all.x = T)

# Missing set to 0
gbd[is.na(gbd)] <- 0

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# correct for colon/colo-rectal cancer proportions
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gbd <- merge(gbd, colon16, by = c("cause", "Age", "Sex"), all.x = T)

gbd$deaths <- ifelse(gbd$cause == "Colon and rectum cancer", gbd$deaths*gbd$proportion, gbd$deaths)
gbd$daly   <- ifelse(gbd$cause == "Colon and rectum cancer", gbd$daly*gbd$proportion, gbd$daly)
gbd$yll    <- ifelse(gbd$cause == "Colon and rectum cancer", gbd$yll*gbd$proportion, gbd$yll)
gbd$yld    <- ifelse(gbd$cause == "Colon and rectum cancer", gbd$yld*gbd$proportion, gbd$yld)

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Set male breast cancer deaths, yll, yld, daly to 0 
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gbd[gbd$cause == "Breast cancer" & gbd$Sex == 1, c("daly","yll", "yld", "deaths")] <- 0

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Merge with population data
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

setwd("C:/Users/Noneof/Documents/HealthLinks/ITHIM_MPO/USA/CalibrationData/USPopulation")

pop <- read.csv(file="age_sex_region20102020-01-08.csv", header = TRUE, stringsAsFactors = F)
names(pop)[names(pop)=="Population"] <- "pop"
gbd <- merge(gbd, pop, by = c("Sex", "Age"), all.x = T)

# Add Region and year
gbd$Region <- "United States"
gbd$Year <- 2015
names(gbd)[names(gbd)=="cause"] <- "Cause"

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Standardize Cause titles
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

gbd$Cause <- gsub("All causes", "All Causes", gbd$Cause)
gbd$Cause <- gsub("Alzheimer's disease and other dementias", "Dementia", gbd$Cause)
gbd$Cause <- gsub("Breast cancer", "Breast Cancer", gbd$Cause)
gbd$Cause <- gsub("Cardiomyopathy and myocarditis", "Inflammatory Heart Disease", gbd$Cause)
gbd$Cause <- gsub("Colon and rectum cancer", "Colon Cancer", gbd$Cause)
gbd$Cause <- gsub("Diabetes mellitus", "Diabetes", gbd$Cause)                                                                                                                                                                          
gbd$Cause <- gsub("Hypertensive heart disease", "Hypertensive Heart Disease", gbd$Cause)
gbd$Cause <- gsub("Ischemic heart disease", "Ischemic Heart Disease", gbd$Cause)
gbd$Cause <- gsub("Major depressive disorder", "Depression", gbd$Cause)
gbd$Cause <- gsub("Road injuries", "Road Traffic Injuries", gbd$Cause)
gbd$Cause <- gsub("Tracheal, bronchus, and lung cancer", "Lung Cancer", gbd$Cause)

# Stroke, acure resp inf does not change

# Sort and write file
gbd <- gbd[order(gbd$Cause, gbd$Sex, gbd$Age), c("Region","Year", "Cause", 
       "Sex","Age","pop","deaths","yll", "yld","daly")]

# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Write out US Burden of Disease file
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
setwd("C:/Users/Noneof/Documents/HealthLinks/ITHIM_MPO/USA/CalibrationData/USGBD")
write.csv(gbd,paste0("USBurdenDisease2015_",format(Sys.time(), "%Y-%m-%d"),".csv"), row.names = F)
